==> blanco.plugin.valueobjectphp_0.0.5-src.zip: blancoValueObjectPhpPlugin/src/blanco/plugin/valueobjectphp/wizards/BlancoValueObjectPhpWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.valueobjectphp.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoValueObjectPhpWizardPage4 extends WizardPage {
    public BlancoValueObjectPhpWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoValueObjectPhp vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoValueObjectPhp vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/valueobjectphp ܂)");
        new Label(container, SWT.NONE).setText("    o[IuWFNg`i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco.php/main ƂȂ܂)");

        setControl(container);
    }
}

==> blanco.plugin.valueobjectphp_0.0.6-src.zip: blancoValueObjectPhpPlugin/src/blanco/plugin/valueobjectphp/wizards/BlancoValueObjectPhpWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.valueobjectphp.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.valueobjectphp.resourcebundle.BlancoValueObjectPhpResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoValueObjectPhpWizardPage4 extends WizardPage {
    private static final BlancoValueObjectPhpResourceBundle fBundle = new BlancoValueObjectPhpResourceBundle();

    public BlancoValueObjectPhpWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoValueObjectPhp vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoValueObjectPhp vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/valueobjectphp ܂)");
        new Label(container, SWT.NONE).setText("    o[IuWFNg`i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE).setText("  4.ꂽ\[XR[hi[tH_");
        new Label(container, SWT.NONE).setText("    Eblanco.php/main (PHP)");

        setControl(container);
    }
}
